@@ -5,7 +5,7 @@
 ;;
 ;; GNAT is provided by AdaCore; see http://libre.adacore.com/
 ;;
-;;; Copyright (C) 2012 - 2021  Free Software Foundation, Inc.
+;;; Copyright (C) 2012 - 2022  Free Software Foundation, Inc.
 ;;
 ;; Author: Stephen Leake <stephen_leake@member.fsf.org>
 ;; Maintainer: Stephen Leake <stephen_leake@member.fsf.org>
@@ -142,17 +142,17 @@ elements of the result may be nil."
 (defun ada-gnat-xref-refs (project item all)
   ;; WORKAROUND: xref 1.3.2 xref-location changed from defclass to cl-defstruct
   (with-no-warnings ;; "unknown slot"
-    (let ((summary (if (functionp 'xref-item-summary) (xref-item-summary item) (oref item :summary)))
-	  (location (if (functionp 'xref-item-location) (xref-item-location item) (oref item :location))))
+    (let ((summary (if (functionp 'xref-item-summary) (xref-item-summary item) (oref item summary)))
+	  (location (if (functionp 'xref-item-location) (xref-item-location item) (oref item location))))
       (let ((file (if (functionp 'xref-file-location-file)
 		      (xref-file-location-file location)
-		    (oref location :file)))
+		    (oref location file)))
 	    (line (if (functionp 'xref-file-location-line)
 		      (xref-file-location-line location)
-		    (oref location :line)))
+		    (oref location line)))
 	    (column (if (functionp 'xref-file-location-column)
 			(xref-file-location-column location)
-		      (oref location :column))))
+		      (oref location column))))
 	(let* ((wisi-xref-full-path t)
 	       (args (cons "-r" (ada-gnat-xref-common-args project summary file line column)))
 	       (result nil))
