@@ -1,7 +1,7 @@
 ;;; ada-process.el --- Generated parser support file  -*- lexical-binding:t -*-
 ;;  command line: wisitoken-bnf-generate.exe  --generate LR1 Ada_Emacs re2c PROCESS text_rep ada.wy
 
-;;  Copyright (C) 2013 - 2019 Free Software Foundation, Inc.
+;;  Copyright (C) 2013 - 2020 Free Software Foundation, Inc.
 
 ;;  This program is free software; you can redistribute it and/or
 ;;  modify it under the terms of the GNU General Public License as
@@ -165,7 +165,7 @@
    case_statement_alternative
    case_statement_alternative_list
    compilation_unit
-   compilation_unit_list
+   compilation
    component_clause
    component_clause_list
    component_declaration
